from setuptools import setup

setup(name='distributions_test_avi',
      version='1.0',
      description='Gaussian distributions',
      packages=['distributions_test'],
      author='avitomar12',
      author_email='avitomar12@gmail.com',
      zip_safe=False)
